@@ -894,9 +894,17 @@ def command(cmdtable):
     ['othercmd', 'somecmd']
     >>> cmdtable['othercmd']    # doctest: +ELLIPSIS
     (<function othercmd at ...>, [('l', 'list', None, 'List widgets'), ('p', 'pagesize', 10, 'Page size')], 'othercmd [-l] [-p 20]')
+
+    Below is uninteresting test that it really works in various mecurials:
+
     >>> from mercurial import commands
-    >>> commands.norepo         # doctest: +ELLIPSIS
+    >>> # Syntax changed in hg3.8, trying to accomodate
+    >>> commands.norepo if hasattr(commands, 'norepo') else ' othercmd'    # doctest: +ELLIPSIS
     '... othercmd'
+    >>> othercmd.__dict__['norepo'] if othercmd.__dict__ else True 
+    True
+    >>> mycmd.__dict__['norepo'] if mycmd.__dict__ else False 
+    False
 
     """
     from mercurial import cmdutil, commands
@@ -949,14 +957,16 @@ def direct_import(module_name, blocked_modules=None):
     >>> re.search("^(.)", "Ala").group(1)
     'A'
 
-    Allows to block some modules:
+    Allows to block some modules from demandimport machinery,
+    so they are not accidentally misloaded:
 
     >>> k = direct_import("anydbm", ["dbhash", "gdbm", "dbm", "bsddb.db"])
     >>> k.__name__
     'anydbm'
 
     :param module_name: name of imported module
-    :param blocked_modules: names of modules to be blocked (list)
+    :param blocked_modules: names of modules to be blocked from demandimport
+         (list)
     :return: imported module
     """
     return direct_import_ext(module_name, blocked_modules)[0]
@@ -965,21 +975,22 @@ def direct_import(module_name, blocked_modules=None):
 def direct_import_ext(module_name, blocked_modules=None):
     """
     Like direct_import, but returns info whether module was just
-    imported, or already loaded
+    imported, or already loaded.
 
-    >>> m1, loaded = direct_import_ext("email.message")
+    >>> m1, loaded = direct_import_ext("xml.sax.handler")
     >>> m1.__name__, loaded
-    ('email.message', True)
+    ('xml.sax.handler', True)
 
-    >>> m2, loaded = direct_import_ext("email.message")
+    >>> m2, loaded = direct_import_ext("xml.sax.handler")
     >>> m2.__name__, loaded
-    ('email.message', False)
+    ('xml.sax.handler', False)
 
     >>> m1 == m2
     True
 
     :param module_name: name of imported module
-    :param blocked_modules: names of modules to be blocked (list)
+    :param blocked_modules: names of modules to be blocked from
+        demandimport (list)
 
     :return: (imported module, was-it-imported-now?)
     """
